==> wao-ui-2.1.2-sources.jar: fr/ifremer/wao/ui/pages/ObsDebSamplingPlan.java <==
/*
 * #%L
 * Wao :: Web Interface
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2011 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;


import fr.ifremer.wao.WaoException;
import fr.ifremer.wao.bean.ConnectedUser;
import fr.ifremer.wao.bean.ObsProgram;
import fr.ifremer.wao.bean.SamplingFilter;
import fr.ifremer.wao.bean.SamplingFilterImpl;
import fr.ifremer.wao.entity.SampleRow;
import fr.ifremer.wao.service.ServiceSampling;
import fr.ifremer.wao.ui.data.ExportStreamResponse;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import fr.ifremer.wao.ui.data.SampleRowDataSource;
import fr.ifremer.wao.ui.services.SampleRowModelFactory;
import org.apache.tapestry5.ComponentResources;
import org.apache.tapestry5.StreamResponse;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.beaneditor.BeanModel;
import org.apache.tapestry5.grid.GridDataSource;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.BeanModelSource;

import java.io.IOException;
import java.io.InputStream;

@RequiresAuthentication(allowedPrograms = {ObsProgram.OBSDEB})
public class ObsDebSamplingPlan {

    /********* Tapestry stuffs **********/

    @Inject
    private BeanModelSource beanModelSource;

    @Inject
    private ComponentResources resources;

    @Inject
    private ServiceSampling serviceSampling;

    /********* Session ************/

    @SessionState
    @Property
    private ConnectedUser connectedUser;

    /********* FILTERS ********/

    public SamplingFilter getSamplingFilter() {
        SamplingFilter samplingFilter = new SamplingFilterImpl();
        samplingFilter.setObsProgram(ObsProgram.OBSDEB);
        return samplingFilter;
    }

    /********* GRID ********/

    private GridDataSource sampleRows;

    @Property
    private SampleRow sampleRow;

    public GridDataSource getSampleRows() {
        if (sampleRows == null) {
            sampleRows = new SampleRowDataSource(getSamplingFilter(), serviceSampling);
        }
        return sampleRows;
    }

    private BeanModel<SampleRow> obsdebSamplingPlanModel;

    public BeanModel<SampleRow> getObsdebSamplingPlanModel() {
        if (obsdebSamplingPlanModel == null) {
            SampleRowModelFactory sampleRowModelFactory = new SampleRowModelFactory(beanModelSource, resources, connectedUser);
            obsdebSamplingPlanModel = sampleRowModelFactory.newModel();
        }
        return obsdebSamplingPlanModel;
    }

    /********** ACTIONS *********/

    StreamResponse onActionFromExportSamplingPlan() {
        return new ExportStreamResponse("wao-echantillonnage-obsdeb") {
            @Override
            public InputStream getStream() throws IOException {
                InputStream csv = null;
                try {
                    csv = serviceSampling.exportSamplingPlanCsv(connectedUser, getSamplingFilter());
                } catch (WaoException eee) {
                    throw new IOException(eee);
                }
                return csv;
            }
        };
    }
}

==> wao-ui-2.1.3-sources.jar: fr/ifremer/wao/ui/pages/ObsDebSamplingPlan.java <==
/*
 * #%L
 * Wao :: Web Interface
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2011 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;

import fr.ifremer.wao.WaoBusinessException;
import fr.ifremer.wao.WaoException;
import fr.ifremer.wao.bean.ConnectedUser;
import fr.ifremer.wao.bean.ObsProgram;
import fr.ifremer.wao.entity.SampleRow;
import fr.ifremer.wao.io.ImportResults;
import fr.ifremer.wao.service.ServiceSampling;
import fr.ifremer.wao.ui.base.SamplingFilterManager;
import fr.ifremer.wao.ui.data.ExportStreamResponse;
import fr.ifremer.wao.ui.data.ImportEngine;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import fr.ifremer.wao.ui.data.SampleRowDataSource;
import fr.ifremer.wao.ui.services.SampleRowModelFactory;
import org.apache.tapestry5.ComponentResources;
import org.apache.tapestry5.StreamResponse;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.beaneditor.BeanModel;
import org.apache.tapestry5.grid.GridDataSource;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.BeanModelSource;

import java.io.IOException;
import java.io.InputStream;

@RequiresAuthentication(allowedPrograms = {ObsProgram.OBSDEB})
public class ObsDebSamplingPlan {

    /********* Tapestry stuffs **********/

    @Inject
    private BeanModelSource beanModelSource;

    @Inject
    private ComponentResources resources;

    @Inject
    private ServiceSampling serviceSampling;

    /********* Session ************/

    @SessionState
    @Property
    private ConnectedUser connectedUser;

    /********* FILTERS ********/

    @Persist
    private SamplingFilterManager filterManager;

    public SamplingFilterManager getFilterManager() {
        if (filterManager == null) {
            filterManager = new SamplingFilterManager(connectedUser, serviceSampling);
        }
        return filterManager;
    }

    /********* GRID ********/

    private GridDataSource sampleRows;

    @Property
    private SampleRow sampleRow;

    public GridDataSource getSampleRows() {
        if (sampleRows == null) {
            sampleRows = new SampleRowDataSource(getFilterManager().getFilter(), serviceSampling);
        }
        return sampleRows;
    }

    private BeanModel<SampleRow> obsdebSamplingPlanModel;

    public BeanModel<SampleRow> getObsdebSamplingPlanModel() {
        if (obsdebSamplingPlanModel == null) {
            SampleRowModelFactory sampleRowModelFactory = new SampleRowModelFactory(beanModelSource, resources, connectedUser);
            obsdebSamplingPlanModel = sampleRowModelFactory.newModel();
        }
        return obsdebSamplingPlanModel;
    }

    /********** IMPORT / EXPORT *********/

    public ImportEngine getSamplingPlanImportEngine() {
        return new ImportEngine() {
            @Override
            public ImportResults execute(InputStream input)
                    throws WaoException, WaoBusinessException {
                ImportResults results = serviceSampling.importSamplingPlanCsv(input, connectedUser);
                return results;
            }
        };
    }

    StreamResponse onActionFromExportSamplingPlan() {
        return new ExportStreamResponse("wao-echantillonnage-obsdeb") {
            @Override
            public InputStream getStream() throws IOException {
                InputStream csv = null;
                try {
                    csv = serviceSampling.exportSamplingPlanCsv(connectedUser, getFilterManager().getFilter());
                } catch (WaoException eee) {
                    throw new IOException(eee);
                }
                return csv;
            }
        };
    }
}
